@@ -1,3 +1,4 @@
+import asyncio
 import io
 import json
 import os.path
@@ -44,7 +45,7 @@ class Dataset(Resource):
                  workload: Workload = Workload("general-large"),
                  fast: bool = False,
                  sample: SampleSettings = SampleSettings(),
-                 task_type: TaskType = TaskType.BinaryClassification,
+                 task_type: TaskType = None,
                  notification: NotificationSettings = None):
         """
         :param client: The Dataset client repository, which can be obtained through an instance of Modela.
@@ -79,12 +80,11 @@ class Dataset(Resource):
             lab = lab.reference
         elif type(lab) == str:
             lab = ObjectReference(Namespace=client.modela.tenant, Name=lab)
+        spec.LabRef = lab
 
         if type(bucket) == VirtualBucket:
             bucket = bucket.name
 
-        # FIXME: https://github.com/metaprov/modelaapi/issues/7
-
         if gen_datasource:
             file_type = FlatFileType.Csv
         else:
@@ -131,8 +131,10 @@ class Dataset(Resource):
 
         self.spec.DatasourceName = datasource.name
         self.spec.Resources = workload
-        self.spec.Task = task_type
-        if task_type != datasource.spec.Task:
+        self.spec.Task = task_type or TaskType.BinaryClassification
+        if not task_type:
+            print("WARNING: No task type was specified. Defaulting to binary classification")
+        elif task_type != datasource.spec.Task:
             print("WARNING: Dataset task type does not match the task type of its Data Source (you: %s, it: %s)" %
                   (task_type.name, datasource.spec.Task.name))
 
@@ -164,6 +166,7 @@ class Dataset(Resource):
             raise ValueError("Dataset {0} has no report.".format(self.name))
 
         return self._client.modela.Report(namespace=self.namespace, name=self.status.ReportName)
+
     @property
     def phase(self) -> DatasetPhase:
         """ The phase specified by the status of the Dataset """
@@ -285,6 +288,11 @@ class Dataset(Resource):
         else:
             raise AttributeError("Object has no client repository")
 
+    async def wait_until_phase(self, phase: DatasetPhase):
+        """ Returns a coroutine which blocks until the specified phase is reached, or the Dataset fails """
+        while self.status.Phase not in (phase, DatasetPhase.Failed):
+            await asyncio.sleep(1/5)
+
     def __repr__(self):
         out = super().__repr__()
         if len(self.status.Statistics.Columns) > 0:
