@@ -7,6 +7,7 @@ from modela.Configuration import datamodel
 from modela.common import Configuration, ConditionStatus, Time, ObjectReference, StatusError, TriggerScheduleEventType
 from modela.inference.common import PredictorConditionType, CanaryMetric, AccessType, PredictorType, ModelDeploymentPhase
 from modela.infra.models import Workload
+from modela.data.models import DataLocation
 from modela.training.common import TaskType
 from modela.training.models import ModelValidation, ModelValidationResult
 
@@ -290,7 +291,7 @@ class PredictorSpec(Configuration):
     The specification to progressively deploy models. ModelDeploymentSpec specifications within Models that have the
     `Canary` field enabled will be progressively deployed according to the specification when they are applied to the Predictor
     """
-    ArtifactsFolder: str = ''
+    ArtifactsFolder: DataLocation = DataLocation()
     """ The data location where artifacts generated by the Predictor will be stored """
     Port: int = 8080
     """
